@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Header: /Users/claude/fuzz/lib/Genezzo/RCS/Tablespace.pm,v 7.10 2006/01/02 10:32:13 claude Exp claude $
+# $Header: /Users/claude/fuzz/lib/Genezzo/RCS/Tablespace.pm,v 7.11 2006/08/01 07:32:42 claude Exp claude $
 #
 # copyright (c) 2003-2006 Jeffrey I Cohen, all rights reserved, worldwide
 #
@@ -29,7 +29,7 @@ BEGIN {
     # set the version for version checking
 #    $VERSION     = 1.00;
     # if using RCS/CVS, this may be preferred
-    $VERSION = do { my @r = (q$Revision: 7.10 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+    $VERSION = do { my @r = (q$Revision: 7.11 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
 
     @ISA         = qw(Exporter);
 #    @EXPORT      = qw(&func1 &func2 &func4 &func5);
@@ -769,8 +769,10 @@ sub TSLoad ()
         # XXX: don't create a new buffer cache if reloading...
         $ts->{bc} = 
           Genezzo::BufCa::BCFile->new(
-                                   blocksize => $self->{blocksize},
-                                   numblocks => $self->{bc_size});
+                                      blocksize => $self->{blocksize},
+                                      numblocks => $self->{bc_size},
+                                      tsname    => $self->{NAME}
+                                      );
 
         unless (defined($ts->{bc}))
         {
